# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmRpmAlternateContentSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'last_refreshed': 'datetime',
        'paths': 'list[str]',
        'remote': 'str'
    }

    attribute_map = {
        'name': 'name',
        'last_refreshed': 'last_refreshed',
        'paths': 'paths',
        'remote': 'remote'
    }

    def __init__(self, name=None, last_refreshed=None, paths=None, remote=None, local_vars_configuration=None):  # noqa: E501
        """RpmRpmAlternateContentSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._last_refreshed = None
        self._paths = None
        self._remote = None
        self.discriminator = None

        self.name = name
        self.last_refreshed = last_refreshed
        if paths is not None:
            self.paths = paths
        self.remote = remote

    @property
    def name(self):
        """Gets the name of this RpmRpmAlternateContentSource.  # noqa: E501

        Name of Alternate Content Source.  # noqa: E501

        :return: The name of this RpmRpmAlternateContentSource.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RpmRpmAlternateContentSource.

        Name of Alternate Content Source.  # noqa: E501

        :param name: The name of this RpmRpmAlternateContentSource.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def last_refreshed(self):
        """Gets the last_refreshed of this RpmRpmAlternateContentSource.  # noqa: E501

        Date of last refresh of AlternateContentSource.  # noqa: E501

        :return: The last_refreshed of this RpmRpmAlternateContentSource.  # noqa: E501
        :rtype: datetime
        """
        return self._last_refreshed

    @last_refreshed.setter
    def last_refreshed(self, last_refreshed):
        """Sets the last_refreshed of this RpmRpmAlternateContentSource.

        Date of last refresh of AlternateContentSource.  # noqa: E501

        :param last_refreshed: The last_refreshed of this RpmRpmAlternateContentSource.  # noqa: E501
        :type: datetime
        """

        self._last_refreshed = last_refreshed

    @property
    def paths(self):
        """Gets the paths of this RpmRpmAlternateContentSource.  # noqa: E501

        List of paths that will be appended to the Remote url when searching for content.  # noqa: E501

        :return: The paths of this RpmRpmAlternateContentSource.  # noqa: E501
        :rtype: list[str]
        """
        return self._paths

    @paths.setter
    def paths(self, paths):
        """Sets the paths of this RpmRpmAlternateContentSource.

        List of paths that will be appended to the Remote url when searching for content.  # noqa: E501

        :param paths: The paths of this RpmRpmAlternateContentSource.  # noqa: E501
        :type: list[str]
        """

        self._paths = paths

    @property
    def remote(self):
        """Gets the remote of this RpmRpmAlternateContentSource.  # noqa: E501

        The remote to provide alternate content source.  # noqa: E501

        :return: The remote of this RpmRpmAlternateContentSource.  # noqa: E501
        :rtype: str
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this RpmRpmAlternateContentSource.

        The remote to provide alternate content source.  # noqa: E501

        :param remote: The remote of this RpmRpmAlternateContentSource.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and remote is None:  # noqa: E501
            raise ValueError("Invalid value for `remote`, must not be `None`")  # noqa: E501

        self._remote = remote

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmRpmAlternateContentSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmRpmAlternateContentSource):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class ArtifactResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pulp_href': 'str',
        'pulp_created': 'datetime',
        'file': 'str',
        'size': 'int',
        'md5': 'str',
        'sha1': 'str',
        'sha224': 'str',
        'sha256': 'str',
        'sha384': 'str',
        'sha512': 'str'
    }

    attribute_map = {
        'pulp_href': 'pulp_href',
        'pulp_created': 'pulp_created',
        'file': 'file',
        'size': 'size',
        'md5': 'md5',
        'sha1': 'sha1',
        'sha224': 'sha224',
        'sha256': 'sha256',
        'sha384': 'sha384',
        'sha512': 'sha512'
    }

    def __init__(self, pulp_href=None, pulp_created=None, file=None, size=None, md5=None, sha1=None, sha224=None, sha256=None, sha384=None, sha512=None, local_vars_configuration=None):  # noqa: E501
        """ArtifactResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pulp_href = None
        self._pulp_created = None
        self._file = None
        self._size = None
        self._md5 = None
        self._sha1 = None
        self._sha224 = None
        self._sha256 = None
        self._sha384 = None
        self._sha512 = None
        self.discriminator = None

        if pulp_href is not None:
            self.pulp_href = pulp_href
        if pulp_created is not None:
            self.pulp_created = pulp_created
        self.file = file
        if size is not None:
            self.size = size
        self.md5 = md5
        self.sha1 = sha1
        self.sha224 = sha224
        self.sha256 = sha256
        self.sha384 = sha384
        self.sha512 = sha512

    @property
    def pulp_href(self):
        """Gets the pulp_href of this ArtifactResponse.  # noqa: E501


        :return: The pulp_href of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._pulp_href

    @pulp_href.setter
    def pulp_href(self, pulp_href):
        """Sets the pulp_href of this ArtifactResponse.


        :param pulp_href: The pulp_href of this ArtifactResponse.  # noqa: E501
        :type: str
        """

        self._pulp_href = pulp_href

    @property
    def pulp_created(self):
        """Gets the pulp_created of this ArtifactResponse.  # noqa: E501

        Timestamp of creation.  # noqa: E501

        :return: The pulp_created of this ArtifactResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._pulp_created

    @pulp_created.setter
    def pulp_created(self, pulp_created):
        """Sets the pulp_created of this ArtifactResponse.

        Timestamp of creation.  # noqa: E501

        :param pulp_created: The pulp_created of this ArtifactResponse.  # noqa: E501
        :type: datetime
        """

        self._pulp_created = pulp_created

    @property
    def file(self):
        """Gets the file of this ArtifactResponse.  # noqa: E501

        The stored file.  # noqa: E501

        :return: The file of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this ArtifactResponse.

        The stored file.  # noqa: E501

        :param file: The file of this ArtifactResponse.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and file is None:  # noqa: E501
            raise ValueError("Invalid value for `file`, must not be `None`")  # noqa: E501

        self._file = file

    @property
    def size(self):
        """Gets the size of this ArtifactResponse.  # noqa: E501

        The size of the file in bytes.  # noqa: E501

        :return: The size of this ArtifactResponse.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ArtifactResponse.

        The size of the file in bytes.  # noqa: E501

        :param size: The size of this ArtifactResponse.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def md5(self):
        """Gets the md5 of this ArtifactResponse.  # noqa: E501

        The MD5 checksum of the file if available.  # noqa: E501

        :return: The md5 of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._md5

    @md5.setter
    def md5(self, md5):
        """Sets the md5 of this ArtifactResponse.

        The MD5 checksum of the file if available.  # noqa: E501

        :param md5: The md5 of this ArtifactResponse.  # noqa: E501
        :type: str
        """

        self._md5 = md5

    @property
    def sha1(self):
        """Gets the sha1 of this ArtifactResponse.  # noqa: E501

        The SHA-1 checksum of the file if available.  # noqa: E501

        :return: The sha1 of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha1

    @sha1.setter
    def sha1(self, sha1):
        """Sets the sha1 of this ArtifactResponse.

        The SHA-1 checksum of the file if available.  # noqa: E501

        :param sha1: The sha1 of this ArtifactResponse.  # noqa: E501
        :type: str
        """

        self._sha1 = sha1

    @property
    def sha224(self):
        """Gets the sha224 of this ArtifactResponse.  # noqa: E501

        The SHA-224 checksum of the file if available.  # noqa: E501

        :return: The sha224 of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha224

    @sha224.setter
    def sha224(self, sha224):
        """Sets the sha224 of this ArtifactResponse.

        The SHA-224 checksum of the file if available.  # noqa: E501

        :param sha224: The sha224 of this ArtifactResponse.  # noqa: E501
        :type: str
        """

        self._sha224 = sha224

    @property
    def sha256(self):
        """Gets the sha256 of this ArtifactResponse.  # noqa: E501

        The SHA-256 checksum of the file if available.  # noqa: E501

        :return: The sha256 of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha256

    @sha256.setter
    def sha256(self, sha256):
        """Sets the sha256 of this ArtifactResponse.

        The SHA-256 checksum of the file if available.  # noqa: E501

        :param sha256: The sha256 of this ArtifactResponse.  # noqa: E501
        :type: str
        """

        self._sha256 = sha256

    @property
    def sha384(self):
        """Gets the sha384 of this ArtifactResponse.  # noqa: E501

        The SHA-384 checksum of the file if available.  # noqa: E501

        :return: The sha384 of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha384

    @sha384.setter
    def sha384(self, sha384):
        """Sets the sha384 of this ArtifactResponse.

        The SHA-384 checksum of the file if available.  # noqa: E501

        :param sha384: The sha384 of this ArtifactResponse.  # noqa: E501
        :type: str
        """

        self._sha384 = sha384

    @property
    def sha512(self):
        """Gets the sha512 of this ArtifactResponse.  # noqa: E501

        The SHA-512 checksum of the file if available.  # noqa: E501

        :return: The sha512 of this ArtifactResponse.  # noqa: E501
        :rtype: str
        """
        return self._sha512

    @sha512.setter
    def sha512(self, sha512):
        """Sets the sha512 of this ArtifactResponse.

        The SHA-512 checksum of the file if available.  # noqa: E501

        :param sha512: The sha512 of this ArtifactResponse.  # noqa: E501
        :type: str
        """

        self._sha512 = sha512

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ArtifactResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ArtifactResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.patchedrpm_uln_remote import PatchedrpmUlnRemote  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException

class TestPatchedrpmUlnRemote(unittest.TestCase):
    """PatchedrpmUlnRemote unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PatchedrpmUlnRemote
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = pulpcore.client.pulp_rpm.models.patchedrpm_uln_remote.PatchedrpmUlnRemote()  # noqa: E501
        if include_optional :
            return PatchedrpmUlnRemote(
                name = '0', 
                url = '0', 
                ca_cert = '0', 
                client_cert = '0', 
                client_key = '0', 
                tls_validation = True, 
                proxy_url = '0', 
                proxy_username = '0', 
                proxy_password = '0', 
                username = '0', 
                password = '0', 
                pulp_labels = {
                    'key' : '0'
                    }, 
                download_concurrency = 1, 
                max_retries = 56, 
                policy = null, 
                total_timeout = 0.0, 
                connect_timeout = 0.0, 
                sock_connect_timeout = 0.0, 
                sock_read_timeout = 0.0, 
                headers = [
                    None
                    ], 
                rate_limit = 56, 
                uln_server_base_url = '0'
            )
        else :
            return PatchedrpmUlnRemote(
        )

    def testPatchedrpmUlnRemote(self):
        """Test PatchedrpmUlnRemote"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages  # noqa: E501

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from pulpcore.client.pulp_rpm.configuration import Configuration


class RpmUpdateRecord(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'repository': 'str',
        'file': 'file'
    }

    attribute_map = {
        'repository': 'repository',
        'file': 'file'
    }

    def __init__(self, repository=None, file=None, local_vars_configuration=None):  # noqa: E501
        """RpmUpdateRecord - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._repository = None
        self._file = None
        self.discriminator = None

        if repository is not None:
            self.repository = repository
        if file is not None:
            self.file = file

    @property
    def repository(self):
        """Gets the repository of this RpmUpdateRecord.  # noqa: E501

        A URI of a repository the new content unit should be associated with.  # noqa: E501

        :return: The repository of this RpmUpdateRecord.  # noqa: E501
        :rtype: str
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this RpmUpdateRecord.

        A URI of a repository the new content unit should be associated with.  # noqa: E501

        :param repository: The repository of this RpmUpdateRecord.  # noqa: E501
        :type: str
        """

        self._repository = repository

    @property
    def file(self):
        """Gets the file of this RpmUpdateRecord.  # noqa: E501

        An uploaded file that may be turned into the artifact of the content unit.  # noqa: E501

        :return: The file of this RpmUpdateRecord.  # noqa: E501
        :rtype: file
        """
        return self._file

    @file.setter
    def file(self, file):
        """Sets the file of this RpmUpdateRecord.

        An uploaded file that may be turned into the artifact of the content unit.  # noqa: E501

        :param file: The file of this RpmUpdateRecord.  # noqa: E501
        :type: file
        """

        self._file = file

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RpmUpdateRecord):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RpmUpdateRecord):
            return True

        return self.to_dict() != other.to_dict()
